@@ -15,18 +15,17 @@
 #include "files.h"
 #include "log.h"
 #include "random.h"
-#include "trinity.h"	// __unused__
 
-int child_read_all_files(__unused__ int childno)
+int child_read_all_files(void)
 {
 	struct stat sb;
-	const char *filename;
 	char *buffer;
 	unsigned int i;
 	int fd;
-	int ret;
 
 	for (i = 0; i < files_in_index; i++) {
+		int ret;
+		const char *filename;
 
 		filename = fileindex[i];
 
