@@ -1,10 +1,23 @@
-#ifndef _TRINITY_COMPAT_H
-#define _TRINITY_COMPAT_H 1
+#pragma once
+
+/* bits/eventfd.h */
+#ifndef EFD_SEMAPHORE
+#define EFD_SEMAPHORE 1
+#endif
+#ifndef EFD_CLOEXEC
+#define EFD_CLOEXEC 02000000
+#endif
+#ifndef EFD_NONBLOCK
+#define EFD_NONBLOCK 04000
+#endif
 
 /* fcntl.h */
 #ifndef AT_EMPTY_PATH
 #define AT_EMPTY_PATH           0x1000
 #endif
+#ifndef AT_SYMLINK_NOFOLLOW
+#define AT_SYMLINK_NOFOLLOW	0x100
+#endif
 
 #ifndef O_PATH
 #define O_PATH        010000000 /* Resolve pathname but do not open file.  */
@@ -14,6 +27,10 @@
 #define O_CLOEXEC       02000000
 #endif
 
+#ifndef O_LARGEFILE
+#define O_LARGEFILE	00100000
+#endif
+
 #ifndef O_TMPFILE
 #define O_TMPFILE	020000000
 #endif
@@ -50,6 +67,22 @@
 #define F_GETOWNER_UIDS	17
 #endif
 
+#ifndef F_OFD_GETLK
+#define F_OFD_GETLK       36
+#define F_OFD_SETLK       37
+#define F_OFD_SETLKW      38
+#endif
+
+/* Flags for SPLICE and VMSPLICE.  */
+#ifndef SPLICE_F_MOVE
+# define SPLICE_F_MOVE		1	/* Move pages instead of copying.  */
+# define SPLICE_F_NONBLOCK	2	/* Don't block on the pipe splicing */
+# define SPLICE_F_MORE		4	/* Expect more data.  */
+#endif
+#ifndef SPLICE_F_GIFT
+# define SPLICE_F_GIFT		8	/* Pages passed in are a gift.  */
+#endif
+
 /* linux/hw_breakpoint.h */
 enum {
         HW_BREAKPOINT_LEN_1 = 1,
@@ -94,6 +127,12 @@ enum {
 #ifndef MADV_NOHUGEPAGE
 #define MADV_NOHUGEPAGE 15
 #endif
+#ifndef MADV_DONTDUMP
+#define MADV_DONTDUMP 16
+#endif
+#ifndef MADV_DODUMP
+#define MADV_DODUMP 17
+#endif
 
 
 /* bits/socket.h */
@@ -223,6 +262,28 @@ enum {
 #define PR_MCE_KILL_GET 34
 #endif
 
+#ifndef PR_SET_MM
+#define PR_SET_MM               35
+#endif
+
+#ifndef PR_SET_CHILD_SUBREAPER
+#define PR_SET_CHILD_SUBREAPER  36
+#define PR_GET_CHILD_SUBREAPER  37
+#define PR_SET_NO_NEW_PRIVS     38
+#define PR_GET_NO_NEW_PRIVS     39
+#define PR_GET_TID_ADDRESS      40
+#endif
+
+#ifndef PR_SET_THP_DISABLE
+#define PR_SET_THP_DISABLE      41
+#define PR_GET_THP_DISABLE      42
+#endif
+
+#ifndef PR_MPX_ENABLE_MANAGEMENT
+#define PR_MPX_ENABLE_MANAGEMENT  43
+#define PR_MPX_DISABLE_MANAGEMENT 44
+#endif
+
 /* linux/rds.h */
 #ifndef RDS_CANCEL_SENT_TO
 #define RDS_CANCEL_SENT_TO              1
@@ -340,6 +401,14 @@ enum kcmp_type {
 #define SO_MAX_PACING_RATE	47
 #endif
 
+#ifndef SO_BPF_EXTENSIONS
+#define SO_BPF_EXTENSIONS       48
+#endif
+
+#ifndef SO_INCOMING_CPU
+#define SO_INCOMING_CPU		49
+#endif
+
 /* linux/tcp.h */
 #ifndef TCP_COOKIE_TRANSACTIONS
 #define TCP_COOKIE_TRANSACTIONS	15
@@ -448,6 +517,9 @@ enum kcmp_type {
 #ifndef IP_UNICAST_IF
 #define IP_UNICAST_IF		50
 #endif
+#ifndef IPPROTO_BEETPH
+#define IPPROTO_BEETPH		94
+#endif
 
 /* linux/in6.h */
 #ifndef IPV6_FLOWINFO
@@ -832,6 +904,9 @@ struct kvm_get_htab_fd {
 #ifndef ETH_P_PRP
 #define ETH_P_PRP	0x88FB
 #endif
+#ifndef ETH_P_TDLS
+#define ETH_P_TDLS	0x890D
+#endif
 #ifndef ETH_P_QINQ1
 #define ETH_P_QINQ1	0x9100
 #endif
@@ -841,5 +916,32 @@ struct kvm_get_htab_fd {
 #ifndef ETH_P_QINQ3
 #define ETH_P_QINQ3	0x9300
 #endif
+#ifndef ETH_P_AF_IUCV
+#define ETH_P_AF_IUCV	0xFBFB
+#endif
 
-#endif	/* _TRINITY_COMPAT_H */
+/* sched.h */
+#ifndef SCHED_DEADLINE
+#define SCHED_DEADLINE 6
+#endif
+#ifndef SCHED_IDLE
+#define SCHED_IDLE 5
+#endif
+
+/* sys/swap.h */
+#ifndef SWAP_FLAG_DISCARD
+#define SWAP_FLAG_DISCARD 0x10000
+#endif
+
+/* unistd.h */
+#ifndef SEEK_DATA
+#define SEEK_DATA 3
+#endif
+#ifndef SEEK_HOLE
+#define SEEK_HOLE 4
+#endif
+
+/* sys/epoll.h */
+#ifndef EPOLLWAKEUP
+#define EPOLLWAKEUP (1u << 29)
+#endif
