@@ -1,24 +1,18 @@
-#ifndef _SANITISE_H
-#define _SANITISE_H 1
+#pragma once
 
 #include "syscall.h"
 
-void sanitise_mmap(int childno);
-void sanitise_rt_sigaction(int childno);
-void sanitise_prctl(int childno);
-void sanitise_perf_event_open(int childno);
-
-void generic_sanitise(int childno);
+void generic_sanitise(struct syscallrecord *rec);
+void generic_free_arg(struct syscallrecord *rec);
 
 unsigned long get_interesting_value(void);
 unsigned int get_interesting_32bit_value(void);
-unsigned long get_reg(void);
 
 void *get_address(void);
 void *get_non_null_address(void);
-unsigned long find_previous_arg_address(unsigned int argnum, unsigned int call, int childno);
+void *get_writable_address(unsigned long size);
+unsigned long find_previous_arg_address(struct syscallrecord *rec, unsigned int argnum);
 struct iovec * alloc_iovec(unsigned int num);
-
 unsigned long get_len(void);
 unsigned int get_pid(void);
 const char * get_filename(void);
@@ -27,4 +21,4 @@ const char * generate_pathname(void);
 
 void gen_unicode_page(char *page);
 
-#endif	/* _SANITISE_H */
+void generate_syscall_args(struct syscallrecord *rec);
