@@ -1,7 +1,9 @@
+#pragma once
+
 /*
  * The Alpha Linux syscall table in all its gory mess.
  *
- * Derived from linux/arch/alpha/include/asm/unistd.h
+ * Derived from arch/alpha/include/uapi/asm/unistd.h
  */
 
 #include "sanitise.h"
@@ -515,4 +517,7 @@ struct syscalltable syscalls_alpha[] = {
 /* 505 */	{ .entry = &syscall_process_vm_writev },
 /* 506 */	{ .entry = &syscall_kcmp },
 /* 507 */	{ .entry = &syscall_finit_module },
+/* 508 */	{ .entry = &syscall_sched_setattr },
+/* 509 */	{ .entry = &syscall_sched_getattr },
+/* 510 */	{ .entry = &syscall_renameat2 },
 };
