@@ -1,3 +1,6 @@
+#include "config.h"
+
+#ifdef USE_APPLETALK
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -7,14 +10,13 @@
 #include <linux/atalk.h>
 #include "random.h"
 #include "net.h"
+#include "utils.h"
 
 void atalk_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_at *atalk;
 
-	atalk = malloc(sizeof(struct sockaddr_at));
-	if (atalk == NULL)
-		return;
+	atalk = zmalloc(sizeof(struct sockaddr_at));
 
 	atalk->sat_family = PF_APPLETALK;
 	atalk->sat_port = rand();
@@ -40,3 +42,4 @@ void atalk_setsockopt(struct sockopt *so)
 {
 	so->level = SOL_ATALK;
 }
+#endif
