@@ -6,7 +6,6 @@
 #include <sys/un.h>
 #include <netinet/in.h>
 #include <stdlib.h>
-#include "maps.h"	// page_rand
 #include "net.h"
 #include "utils.h"	// ARRAY_SIZE
 #include "compat.h"
@@ -15,9 +14,7 @@ void atmpvc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_atmpvc *atmpvc;
 
-	atmpvc = malloc(sizeof(struct sockaddr_atmpvc));
-	if (atmpvc == NULL)
-		return;
+	atmpvc = zmalloc(sizeof(struct sockaddr_atmpvc));
 
 	atmpvc->sap_family = PF_ATMPVC;
 	atmpvc->sap_addr.itf = rand();
@@ -32,9 +29,7 @@ void atmsvc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	struct sockaddr_atmsvc *atmsvc;
 	unsigned int i;
 
-	atmsvc = malloc(sizeof(struct sockaddr_atmsvc));
-	if (atmsvc == NULL)
-		return;
+	atmsvc = zmalloc(sizeof(struct sockaddr_atmsvc));
 
 	atmsvc->sas_family = PF_ATMSVC;
 	for (i = 0; i < ATM_ESA_LEN; i++)
