@@ -19,9 +19,7 @@ void caif_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	struct sockaddr_caif *caif;
 	unsigned int i;
 
-	caif = malloc(sizeof(struct sockaddr_caif));
-	if (caif == NULL)
-		return;
+	caif = zmalloc(sizeof(struct sockaddr_caif));
 
 	caif->family = PF_CAIF;
 	caif->u.at.type = rand();
