@@ -4,7 +4,6 @@
 #include <netinet/in.h>
 #include <linux/dn.h>
 #include <stdlib.h>
-#include "maps.h"	// page_rand
 #include "net.h"
 #include "random.h"
 #include "utils.h"	// ARRAY_SIZE
@@ -15,9 +14,7 @@ void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	struct sockaddr_dn *dn;
 	unsigned int i;
 
-	dn = malloc(sizeof(struct sockaddr_dn));
-	if (dn == NULL)
-		return;
+	dn = zmalloc(sizeof(struct sockaddr_dn));
 
 	dn->sdn_family = PF_DECnet;
 	dn->sdn_flags = rand();
