@@ -1,7 +1,9 @@
+#include "config.h"
+
+#ifdef USE_IPV6
 #include <stdlib.h>
 #include <linux/icmpv6.h>
 #include "net.h"
-#include "maps.h"	// page_rand
 #include "compat.h"
 #include "utils.h"	// ARRAY_SIZE
 
@@ -17,3 +19,4 @@ void icmpv6_setsockopt(struct sockopt *so)
 	val = rand() % NR_SOL_ICMPV6_OPTS;
 	so->optname = icmpv6_opts[val];
 }
+#endif
