@@ -8,7 +8,6 @@
 #include <stdlib.h>
 #include "config.h"
 #include "net.h"
-#include "maps.h"	// page_rand
 #include "random.h"
 #include "utils.h"	// ARRAY_SIZE
 #include "compat.h"
@@ -18,9 +17,8 @@ void llc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	struct sockaddr_llc *llc;
 	unsigned int i;
 
-	llc = malloc(sizeof(struct sockaddr_llc));
-	if (llc == NULL)
-		return;
+	llc = zmalloc(sizeof(struct sockaddr_llc));
+
 	llc->sllc_family = AF_LLC;
 	llc->sllc_arphrd = ARPHRD_ETHER;
 	llc->sllc_test = rand();
