@@ -1,7 +1,9 @@
+#include "config.h"
+
+#ifdef USE_NETROM
 #include <stdlib.h>
 #include <netrom/netrom.h>
 #include "net.h"
-#include "maps.h"	// page_rand
 #include "compat.h"
 #include "utils.h"	// ARRAY_SIZE
 
@@ -18,3 +20,4 @@ void netrom_setsockopt(struct sockopt *so)
 	val = rand() % NR_SOL_NETROM_OPTS;
 	so->optname = netrom_opts[val];
 }
+#endif
