@@ -1,3 +1,6 @@
+#include "config.h"
+
+#ifdef USE_ROSE
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -6,9 +9,8 @@
 #include <linux/ax25.h> /* for ax25_address in rose.h */
 #include <netrose/rose.h>
 #include <stdlib.h>
-#include "maps.h"	// page_rand
 #include "net.h"
-#include "maps.h"	// page_rand
+#include "random.h"
 #include "utils.h"	// ARRAY_SIZE
 #include "compat.h"
 
@@ -16,9 +18,7 @@ void rose_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_rose *rose;
 
-	rose = malloc(sizeof(struct sockaddr_rose));
-	if (rose == NULL)
-		return;
+	rose = zmalloc(sizeof(struct sockaddr_rose));
 
 	rose->srose_family = PF_ROSE;
 	rose->srose_addr.rose_addr[0] = rand();
@@ -27,12 +27,10 @@ void rose_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	rose->srose_addr.rose_addr[3] = rand();
 	rose->srose_addr.rose_addr[4] = rand();
 
-	memcpy(rose->srose_call.ax25_call, page_rand, 7);
+	generate_rand_bytes((unsigned char *) rose->srose_call.ax25_call, 7 * 2);
 
 	rose->srose_ndigis = rand();
 
-	memcpy(rose->srose_digi.ax25_call, page_rand + 7, 7);
-
 	*addr = (struct sockaddr *) rose;
 	*addrlen = sizeof(struct sockaddr_rose);
 }
@@ -51,3 +49,4 @@ void rose_setsockopt(struct sockopt *so)
 	val = rand() % NR_SOL_ROSE_OPTS;
 	so->optname = rose_opts[val];
 }
+#endif
