@@ -1,7 +1,6 @@
 #include <stdlib.h>
 #include <linux/filter.h>
 #include "net.h"
-#include "maps.h"	// page_rand
 #include "compat.h"
 #include "utils.h"	// ARRAY_SIZE
 
@@ -17,7 +16,7 @@ static const unsigned int socket_opts[] = { SO_DEBUG, SO_REUSEADDR, SO_TYPE, SO_
 	SO_PASSSEC, SO_TIMESTAMPNS, SO_MARK, SO_TIMESTAMPING,
 	SO_PROTOCOL, SO_DOMAIN, SO_RXQ_OVFL, SO_WIFI_STATUS,
 	SO_PEEK_OFF, SO_NOFCS, SO_LOCK_FILTER, SO_SELECT_ERR_QUEUE,
-	SO_BUSY_POLL, SO_MAX_PACING_RATE };
+	SO_BUSY_POLL, SO_MAX_PACING_RATE, SO_BPF_EXTENSIONS, SO_INCOMING_CPU };
 
 void socket_setsockopt(struct sockopt *so)
 {
@@ -40,11 +39,15 @@ void socket_setsockopt(struct sockopt *so)
 		so->optlen = sizeof(struct timeval);
 		break;
 
-	case SO_ATTACH_FILTER:
-		gen_bpf((unsigned long *) page_rand, NULL);
-		so->optlen = sizeof(struct sock_fprog);
-		break;
+	case SO_ATTACH_FILTER: {
+		unsigned long *optval = NULL, optlen = 0;
 
+		bpf_gen_filter(&optval, &optlen);
+
+		so->optval = (unsigned long) optval;
+		so->optlen = optlen;
+		break;
+	}
 	default:
 		break;
 	}
