@@ -13,9 +13,8 @@ void tipc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_tipc *tipc;
 
-	tipc = malloc(sizeof(struct sockaddr_tipc));
-	if (tipc == NULL)
-		return;
+	tipc = zmalloc(sizeof(struct sockaddr_tipc));
+
 	tipc->family = AF_TIPC;
 	tipc->addrtype = rand();
 	tipc->scope = rand();
@@ -60,5 +59,5 @@ void tipc_setsockopt(struct sockopt *so)
 	val = rand() % NR_SOL_TIPC_OPTS;
 	so->optname = tipc_opts[val];
 
-	so->optval = sizeof(__u32);
+	so->optlen = sizeof(__u32);
 }
