@@ -1,9 +1,9 @@
 #include <stdlib.h>
 #include <netinet/udp.h>
 #include "net.h"
-#include "maps.h"	// page_rand
-#include "compat.h"
+#include "random.h"
 #include "utils.h"	// ARRAY_SIZE
+#include "compat.h"
 
 #define NR_SOL_UDP_OPTS ARRAY_SIZE(udp_opts)
 static const unsigned int udp_opts[] = { UDP_CORK, UDP_ENCAP };
@@ -11,6 +11,7 @@ static const unsigned int udp_opts[] = { UDP_CORK, UDP_ENCAP };
 void udp_setsockopt(struct sockopt *so)
 {
 	unsigned char val;
+	char *optval;
 
 	so->level = SOL_UDP;
 
@@ -21,7 +22,8 @@ void udp_setsockopt(struct sockopt *so)
 	case UDP_CORK:
 		break;
 	case UDP_ENCAP:
-		page_rand[0] = (rand() % 3) + 1;        // Encapsulation types.
+		optval = (char *) so->optval;
+		optval[0] = rand_range(1, 3);        // Encapsulation types.
 		break;
 	default:
 		break;
