@@ -5,22 +5,19 @@
 #include <linux/x25.h>
 #include <stdlib.h>
 #include "net.h"
-#include "maps.h"	// page_rand
 #include "random.h"
+#include "utils.h"
 
 void x25_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_x25 *x25;
 	unsigned int len;
 
-	x25 = malloc(sizeof(struct sockaddr_x25));
-	if (x25 == NULL)
-		return;
+	x25 = zmalloc(sizeof(struct sockaddr_x25));
 
 	x25->sx25_family = PF_X25;
 	len = rand() % 15;
-	memset(&page_rand[len], 0, 1);
-	strncpy(x25->sx25_addr.x25_addr, page_rand, len);
+	generate_rand_bytes((unsigned char *) x25->sx25_addr.x25_addr, len);
 	*addr = (struct sockaddr *) x25;
 	*addrlen = sizeof(struct sockaddr_x25);
 }
@@ -33,8 +30,12 @@ void x25_rand_socket(struct socket_triplet *st)
 
 void x25_setsockopt(struct sockopt *so)
 {
+	unsigned int *optval;
+
 	so->level = SOL_X25;
 
-	page_rand[0] = rand_bool();
-	so->optval = sizeof(int);
+	optval = (unsigned int *) so->optval;
+	*optval = rand_bool();
+
+	so->optlen = sizeof(int);
 }
