@@ -18,7 +18,7 @@ unsigned long get_len(void)
 
 	case 0:	i &= 0xff;
 		break;
-	case 1: i &= page_size;
+	case 1: i &= page_size - 1;
 		break;
 	case 2:	i &= 0xffff;
 		break;
@@ -26,7 +26,7 @@ unsigned long get_len(void)
 		break;
 	case 4:	i &= 0xffffffff;
 		break;
-	default:
+	case 5:
 		// Pass through
 		break;
 	}
@@ -37,7 +37,7 @@ unsigned long get_len(void)
 
 	/* we might get lucky if something is counting ints/longs etc. */
 	if (rand() % 100 < 25) {
-		int _div = 1 << ((rand() % 4) + 1);      /* 2,4,8 or 16 */
+		int _div = 1 << rand_range(1, 4);	/* 2,4,8 or 16 */
 		i /= _div;
 	}
 
