@@ -6,17 +6,19 @@
 #include <stdlib.h>
 #include "shm.h"
 #include "sanitise.h"
+#include "syscall.h"
+#include "trinity.h"
 #include "compat.h"
 
-static void sanitise_linkat(int childno)
+static void sanitise_linkat(struct syscallrecord *rec)
 {
 	/* .. If oldpath is relative and olddirfd is the special value AT_FDCWD, then oldpath is
 	 * interpreted relative to the current working directory of the calling process  */
 	if ((rand() % 100) == 0)
-		shm->a1[childno] = AT_FDCWD;
+		rec->a1 = AT_FDCWD;
 }
 
-struct syscall syscall_linkat = {
+struct syscallentry syscall_linkat = {
 	.name = "linkat",
 	.num_args = 5,
 	.arg1name = "olddfd",
