@@ -2,26 +2,28 @@
  * SYSCALL_DEFINE1(mlockall, int, flags)
  */
 #include <stdlib.h>
-#include "sanitise.h"
 #include "random.h"
+#include "sanitise.h"
 #include "shm.h"
+#include "syscall.h"
+#include "trinity.h"
 
 #define MCL_CURRENT     1
 #define MCL_FUTURE      2
 
-static void sanitise_mlockall(int childno)
+static void sanitise_mlockall(struct syscallrecord *rec)
 {
-	if (shm->a1[childno] != 0)
+	if (rec->a1 != 0)
 		return;
 
 	if (rand_bool())
-		shm->a1[childno] = MCL_CURRENT;
+		rec->a1 = MCL_CURRENT;
 	else
-		shm->a1[childno] = MCL_FUTURE;
+		rec->a1 = MCL_FUTURE;
 }
 
 
-struct syscall syscall_mlockall = {
+struct syscallentry syscall_mlockall = {
 	.name = "mlockall",
 	.num_args = 1,
 	.arg1name = "flags",
