@@ -5,20 +5,22 @@
 #include "random.h"
 #include "sanitise.h"
 #include "shm.h"
+#include "syscall.h"
+#include "trinity.h"
 
 #define MS_ASYNC        1               /* Sync memory asynchronously.  */
 #define MS_SYNC         4               /* Synchronous memory sync.  */
 #define MS_INVALIDATE   2               /* Invalidate the caches.  */
 
-static void sanitise_msync(int childno)
+static void sanitise_msync(struct syscallrecord *rec)
 {
-       (void) common_set_mmap_ptr_len(childno);
+       (void) common_set_mmap_ptr_len();
 
 	if (rand_bool())
-		shm->a3[childno] |= MS_INVALIDATE;
+		rec->a3 |= MS_INVALIDATE;
 }
 
-struct syscall syscall_msync = {
+struct syscallentry syscall_msync = {
 	.name = "msync",
 	.num_args = 3,
 	.arg1name = "start",
