@@ -10,33 +10,36 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <errno.h>
+#include "log.h"
+#include "maps.h"
+#include "perf.h"
 #include "perf_event.h"
 #include "random.h"
 #include "sanitise.h"
-#include "maps.h"
 #include "shm.h"
-#include "log.h"
+#include "syscall.h"
+#include "trinity.h"
 #include "compat.h"
 
 #define SYSFS "/sys/bus/event_source/devices/"
 
 struct generic_event_type {
-	char *name;
-	char *value;
+	const char *name;
+	const char *value;
 	long long config;
 	long long config1;
 	long long config2;
 };
 
 struct format_type {
-	char *name;
-	char *value;
+	const char *name;
+	const char *value;
 	int field;
 	unsigned long long mask;
 };
 
 struct pmu_type {
-	char *name;
+	const char *name;
 	int type;
 	int num_formats;
 	int num_generic_events;
@@ -44,9 +47,9 @@ struct pmu_type {
 	struct generic_event_type *generic_events;
 };
 
-static int num_pmus=0;
-
-static struct pmu_type *pmus=NULL;
+/* Not static so other tools can access the PMU data */
+int num_pmus=0;
+struct pmu_type *pmus=NULL;
 
 
 #define FIELD_UNKNOWN	0
@@ -56,9 +59,9 @@ static struct pmu_type *pmus=NULL;
 #define MAX_FIELDS	4
 
 
-static int parse_format(char *string, int *field_type, unsigned long long *mask) {
+static int parse_format(const char *string, int *field_type, unsigned long long *mask) {
 
-	int i,firstnum,secondnum,shift,bits;
+	int i, secondnum, bits;
 	char format_string[BUFSIZ];
 
 	*mask=0;
@@ -90,6 +93,7 @@ static int parse_format(char *string, int *field_type, unsigned long long *mask)
 	}
 
 	while(1) {
+		int firstnum, shift;
 
 		/* Read first number */
 		i++;
@@ -159,7 +163,7 @@ static unsigned long long separate_bits(unsigned long long value,
 	return result;
 }
 
-static int update_configs(int pmu, char *field,
+static int update_configs(int pmu, const char *field,
 			long long value,
 			long long *c,
 			long long *c1,
@@ -193,15 +197,16 @@ static int update_configs(int pmu, char *field,
 	return 0;
 }
 
-static int parse_generic(int pmu, char *value,
+static int parse_generic(int pmu, const char *value,
 			long long *config, long long *config1, long long *config2) {
 
 	long long c=0,c1=0,c2=0,temp;
 	char field[BUFSIZ];
-	int i,ptr=0;
+	int ptr=0;
 	int base=10;
 
 	while(1) {
+		int i;
 		i=0;
 		while(1) {
 			field[i]=value[ptr];
@@ -865,6 +870,8 @@ static long long random_sample_type(void)
 		sample_type |= PERF_SAMPLE_IDENTIFIER;
 	if (rand_bool())
 		sample_type |= PERF_SAMPLE_TRANSACTION;
+	if (rand_bool())
+		sample_type |= PERF_SAMPLE_REGS_INTR;
 
 	return sample_type;
 }
@@ -893,7 +900,7 @@ static int random_attr_size(void) {
 
 	int size=0;
 
-	switch(rand() % 8) {
+	switch(rand() % 9) {
 	case 0:	size = PERF_ATTR_SIZE_VER0;
 		break;
 	case 1: size = PERF_ATTR_SIZE_VER1;
@@ -902,13 +909,15 @@ static int random_attr_size(void) {
 		break;
 	case 3: size = PERF_ATTR_SIZE_VER3;
 		break;
-	case 4: size = sizeof(struct perf_event_attr);
+	case 4: size = PERF_ATTR_SIZE_VER4;
 		break;
-	case 5: size = rand32();
+	case 5: size = sizeof(struct perf_event_attr);
 		break;
-	case 6:	size = get_len();
+	case 6: size = rand32();
 		break;
-	case 7: size = 0;
+	case 7:	size = get_len();
+		break;
+	case 8: size = 0;
 		break;
 	default:
 		break;
@@ -940,6 +949,8 @@ static long long random_branch_sample_type(void)
 		branch_sample |= PERF_SAMPLE_BRANCH_ANY_RETURN;
 	if (rand_bool())
 		branch_sample |= PERF_SAMPLE_BRANCH_IND_CALL;
+	if (rand_bool())
+		branch_sample |= PERF_SAMPLE_BRANCH_COND;
 
 	/* Transactional Memory Types */
 	if (rand_bool())
@@ -993,6 +1004,8 @@ static void create_mostly_valid_counting_event(struct perf_event_attr *attr,
 	attr->exclude_guest = rand_bool();
 	attr->exclude_callchain_kernel = rand_bool();
 	attr->exclude_callchain_user = rand_bool();
+	attr->mmap2 = rand_bool();
+	attr->comm_exec = rand_bool();
 
 	/* wakeup events not relevant */
 
@@ -1054,6 +1067,8 @@ static void create_mostly_valid_sampling_event(struct perf_event_attr *attr,
 	attr->exclude_guest = rand_bool();
 	attr->exclude_callchain_kernel = rand_bool();
 	attr->exclude_callchain_user = rand_bool();
+	attr->mmap2 = rand_bool();
+	attr->comm_exec = rand_bool();
 
 	attr->wakeup_events = rand32();
 
@@ -1087,6 +1102,36 @@ static void create_mostly_valid_sampling_event(struct perf_event_attr *attr,
 
 }
 
+
+/* Creates a global event: one that is not per-process, but system-wide	*/
+/* To be valid must be created with pid=-1 and cpu being a valid CPU.   */
+/* Also usually only root can create these unless                       */
+/*    /proc/sys/kernel/perf_event_paranoid is less than 1.              */
+/* Most custom PMU types (uncore/northbridge/RAPL) are covered here.    */
+
+static void create_mostly_valid_global_event(struct perf_event_attr *attr,
+						int group_leader)
+{
+
+	attr->type = random_event_type();
+	attr->size = random_attr_size();
+	attr->config = random_event_config(&attr->type,
+					&attr->config1,
+					&attr->config2);
+
+	attr->read_format = random_read_format();
+
+	/* Bitfield parameters, mostly boolean */
+	attr->disabled = rand_bool();
+	attr->inherit = rand_bool();
+	if (group_leader) {
+		attr->pinned = rand_bool();
+	}
+
+	/* Not setting most other paramaters */
+	/* As they tend to be not valid in a global event */
+}
+
 /* Creates a completely random event, unlikely to be valid */
 static void create_random_event(struct perf_event_attr *attr)
 {
@@ -1126,6 +1171,8 @@ static void create_random_event(struct perf_event_attr *attr)
 	attr->exclude_guest = rand_bool();
 	attr->exclude_callchain_kernel = rand_bool();
 	attr->exclude_callchain_user = rand_bool();
+	attr->mmap2 = rand_bool();
+	attr->comm_exec = rand_bool();
 
 	attr->wakeup_events=rand32();
 
@@ -1144,18 +1191,17 @@ static void create_random_event(struct perf_event_attr *attr)
 
 }
 
-void sanitise_perf_event_open(int childno)
+void sanitise_perf_event_open(struct syscallrecord *rec)
 {
 	struct perf_event_attr *attr;
 	unsigned long flags;
 	pid_t pid;
 	int group_leader=0;
+	void *addr;
 
-	shm->a1[childno] = (unsigned long)page_rand;
-	attr = (struct perf_event_attr *)shm->a1[childno];
-
-	/* this makes sure we clear out the reserved fields. */
-	memset(page_rand, 0, sizeof(struct perf_event_attr));
+	addr = zmalloc(sizeof(struct perf_event_attr));
+	rec->a1 = (unsigned long) addr;
+	attr = (struct perf_event_attr *) addr;
 
 	/* cpu */
 	/* requires ROOT to select specific CPU if pid==-1 (all processes) */
@@ -1164,7 +1210,7 @@ void sanitise_perf_event_open(int childno)
 	switch(rand() % 2) {
 	case 0:
 		/* Any CPU */
-		shm->a3[childno] = -1;
+		rec->a3 = -1;
 		break;
 	case 1:
 		/* Default to the get_cpu() value */
@@ -1179,13 +1225,13 @@ void sanitise_perf_event_open(int childno)
 	/* was properly set up to be a group master              */
 	switch (rand() % 3) {
 	case 0:
-		shm->a4[childno] = -1;
+		rec->a4 = -1;
 		group_leader = 1;
 		break;
 	case 1:
 		/* Try to get a previous random perf_event_open() fd  */
 		/* It's unclear whether get_random_fd() would do this */
-		shm->a4[childno] = rand() % 1024;
+		rec->a4 = rand() % 1024;
 		break;
 	case 2:
 		/* Rely on ARG_FD */
@@ -1206,8 +1252,10 @@ void sanitise_perf_event_open(int childno)
 			flags |= PERF_FLAG_FD_OUTPUT;
 		if (rand_bool())
 			flags |= PERF_FLAG_PID_CGROUP;
+		if (rand_bool())
+			flags |= PERF_FLAG_FD_CLOEXEC;
 	}
-	shm->a5[childno] = flags;
+	rec->a5 = flags;
 
 	/* pid */
 	/* requires ROOT to select pid that doesn't belong to us */
@@ -1235,10 +1283,10 @@ void sanitise_perf_event_open(int childno)
 			break;
 		}
 	}
-	shm->a2[childno] = pid;
+	rec->a2 = pid;
 
 	/* set up attr structure */
-	switch (rand() % 3) {
+	switch (rand() % 4) {
 	case 0:
 		create_mostly_valid_counting_event(attr,group_leader);
 		break;
@@ -1246,6 +1294,9 @@ void sanitise_perf_event_open(int childno)
 		create_mostly_valid_sampling_event(attr,group_leader);
 		break;
 	case 2:
+		create_mostly_valid_global_event(attr,group_leader);
+		break;
+	case 3:
 		create_random_event(attr);
 		break;
 	default:
@@ -1253,7 +1304,12 @@ void sanitise_perf_event_open(int childno)
 	}
 }
 
-struct syscall syscall_perf_event_open = {
+static void post_perf_event_open(struct syscallrecord *rec)
+{
+	freeptr(&rec->a1);
+}
+
+struct syscallentry syscall_perf_event_open = {
 	.name = "perf_event_open",
 	.num_args = 5,
 	.arg1name = "attr_uptr",
@@ -1273,6 +1329,7 @@ struct syscall syscall_perf_event_open = {
 		},
 	},
 	.sanitise = sanitise_perf_event_open,
+	.post = post_perf_event_open,
 	.init = init_pmus,
-	.flags = NEED_ALARM,
+	.flags = NEED_ALARM | IGNORE_ENOSYS,
 };
