@@ -3,35 +3,32 @@
 	int, fd_out, loff_t __user *, off_out,
 	size_t, len, unsigned int, flags)
  */
+#include <fcntl.h>
 #include <stdlib.h>
-#include "sanitise.h"
 #include "random.h"
+#include "sanitise.h"
 #include "shm.h"
+#include "syscall.h"
+#include "trinity.h"
+#include "compat.h"
 
-# define SPLICE_F_MOVE          1       /* Move pages instead of copying.  */
-# define SPLICE_F_NONBLOCK      2       /* Don't block on the pipe splicing
-                                           (but we may still block on the fd
-                                           we splice from/to).  */
-# define SPLICE_F_MORE          4       /* Expect more data.  */
-# define SPLICE_F_GIFT          8       /* Pages passed in are a gift.  */
-
-static void sanitise_splice(int childno)
+static void sanitise_splice(struct syscallrecord *rec)
 {
 	if ((rand() % 10) < 3)
 		return;
 
 	if (rand_bool()) {
-		shm->a1[childno] = shm->pipe_fds[rand() % MAX_PIPE_FDS];
-		shm->a2[childno] = 0;
+		rec->a1 = shm->pipe_fds[rand() % MAX_PIPE_FDS];
+		rec->a2 = 0;
 	}
 
 	if (rand_bool()) {
-		shm->a3[childno] = shm->pipe_fds[rand() % MAX_PIPE_FDS];
-		shm->a4[childno] = 0;
+		rec->a3 = shm->pipe_fds[rand() % MAX_PIPE_FDS];
+		rec->a4 = 0;
 	}
 }
 
-struct syscall syscall_splice = {
+struct syscallentry syscall_splice = {
 	.name = "splice",
 	.num_args = 6,
 	.arg1name = "fd_in",
